#[repr(u8)]pub enum Pt0Ac {
PT0_AC_0 = 0,
PT0_AC_1 = 1,
PT0_AC_2 = 2,
PT0_AC_3 = 3,
}Variants
PT0_AC_0 = 0
Force the A input in this product term to a logical zero
PT0_AC_1 = 1
Pass the A input in this product term
PT0_AC_2 = 2
Complement the A input in this product term
PT0_AC_3 = 3
Force the A input in this product term to a logical one
Implementations