#[repr(u8)]pub enum Pt3Ac {
PT3_AC_0 = 0,
PT3_AC_1 = 1,
PT3_AC_2 = 2,
PT3_AC_3 = 3,
}Variants
PT3_AC_0 = 0
Force the A input in this product term to a logical zero.
PT3_AC_1 = 1
Pass the A input in this product term.
PT3_AC_2 = 2
Complement the A input in this product term.
PT3_AC_3 = 3
Force the A input in this product term to a logical one.
Implementations