#[repr(u8)]pub enum Pt3Bc {
PT3_BC_0 = 0,
PT3_BC_1 = 1,
PT3_BC_2 = 2,
PT3_BC_3 = 3,
}Variants
PT3_BC_0 = 0
Force the B input in this product term to a logical zero
PT3_BC_1 = 1
Pass the B input in this product term
PT3_BC_2 = 2
Complement the B input in this product term
PT3_BC_3 = 3
Force the B input in this product term to a logical one
Implementations