#[repr(u8)]pub enum Pt3Dc {
PT3_DC_0 = 0,
PT3_DC_1 = 1,
PT3_DC_2 = 2,
PT3_DC_3 = 3,
}Variants
PT3_DC_0 = 0
Force the D input in this product term to a logical zero.
PT3_DC_1 = 1
Pass the D input in this product term.
PT3_DC_2 = 2
Complement the D input in this product term.
PT3_DC_3 = 3
Force the D input in this product term to a logical one.
Implementations