#[repr(u8)]pub enum Pt0Cc {
PT0_CC_0 = 0,
PT0_CC_1 = 1,
PT0_CC_2 = 2,
PT0_CC_3 = 3,
}Variants
PT0_CC_0 = 0
Force the C input in this product term to a logical zero
PT0_CC_1 = 1
Pass the C input in this product term
PT0_CC_2 = 2
Complement the C input in this product term
PT0_CC_3 = 3
Force the C input in this product term to a logical one
Implementations