#[repr(u8)]pub enum Pt2Bc {
PT2_BC_0 = 0,
PT2_BC_1 = 1,
PT2_BC_2 = 2,
PT2_BC_3 = 3,
}Variants
PT2_BC_0 = 0
Force the B input in this product term to a logical zero
PT2_BC_1 = 1
Pass the B input in this product term
PT2_BC_2 = 2
Complement the B input in this product term
PT2_BC_3 = 3
Force the B input in this product term to a logical one
Implementations